@@ -88,6 +88,7 @@ from .type_defs import (
     GetEnvironmentTemplateVersionOutputTypeDef,
     GetRepositoryOutputTypeDef,
     GetRepositorySyncStatusOutputTypeDef,
+    GetResourcesSummaryOutputTypeDef,
     GetServiceInstanceOutputTypeDef,
     GetServiceOutputTypeDef,
     GetServiceTemplateOutputTypeDef,
@@ -635,6 +636,14 @@ class ProtonClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#get_repository_sync_status)
         """
 
+    def get_resources_summary(self) -> GetResourcesSummaryOutputTypeDef:
+        """
+        Get counts of Proton resources.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.get_resources_summary)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#get_resources_summary)
+        """
+
     def get_service(self, *, name: str) -> GetServiceOutputTypeDef:
         """
         Get detailed data for a service.
