@@ -59,6 +59,7 @@ __all__ = (
     "CompatibleEnvironmentTemplateInputTypeDef",
     "CompatibleEnvironmentTemplateTypeDef",
     "ComponentSummaryTypeDef",
+    "ResourceCountsSummaryTypeDef",
     "TagTypeDef",
     "RepositoryBranchInputTypeDef",
     "EnvironmentTemplateTypeDef",
@@ -161,6 +162,7 @@ __all__ = (
     "UpdateServiceTemplateVersionInputRequestTypeDef",
     "ServiceTemplateVersionTypeDef",
     "ListComponentsOutputTypeDef",
+    "CountsSummaryTypeDef",
     "CreateComponentInputRequestTypeDef",
     "CreateEnvironmentAccountConnectionInputRequestTypeDef",
     "CreateEnvironmentTemplateInputRequestTypeDef",
@@ -260,6 +262,7 @@ __all__ = (
     "DeleteServiceTemplateVersionOutputTypeDef",
     "GetServiceTemplateVersionOutputTypeDef",
     "UpdateServiceTemplateVersionOutputTypeDef",
+    "GetResourcesSummaryOutputTypeDef",
     "GetRepositorySyncStatusOutputTypeDef",
     "GetTemplateSyncStatusOutputTypeDef",
     "CreateEnvironmentTemplateVersionInputRequestTypeDef",
@@ -484,6 +487,30 @@ class ComponentSummaryTypeDef(_RequiredComponentSummaryTypeDef, _OptionalCompone
     pass
 
 
+_RequiredResourceCountsSummaryTypeDef = TypedDict(
+    "_RequiredResourceCountsSummaryTypeDef",
+    {
+        "total": int,
+    },
+)
+_OptionalResourceCountsSummaryTypeDef = TypedDict(
+    "_OptionalResourceCountsSummaryTypeDef",
+    {
+        "behindMajor": int,
+        "behindMinor": int,
+        "failed": int,
+        "upToDate": int,
+    },
+    total=False,
+)
+
+
+class ResourceCountsSummaryTypeDef(
+    _RequiredResourceCountsSummaryTypeDef, _OptionalResourceCountsSummaryTypeDef
+):
+    pass
+
+
 TagTypeDef = TypedDict(
     "TagTypeDef",
     {
@@ -2062,6 +2089,20 @@ ListComponentsOutputTypeDef = TypedDict(
     },
 )
 
+CountsSummaryTypeDef = TypedDict(
+    "CountsSummaryTypeDef",
+    {
+        "components": ResourceCountsSummaryTypeDef,
+        "environmentTemplates": ResourceCountsSummaryTypeDef,
+        "environments": ResourceCountsSummaryTypeDef,
+        "pipelines": ResourceCountsSummaryTypeDef,
+        "serviceInstances": ResourceCountsSummaryTypeDef,
+        "serviceTemplates": ResourceCountsSummaryTypeDef,
+        "services": ResourceCountsSummaryTypeDef,
+    },
+    total=False,
+)
+
 _RequiredCreateComponentInputRequestTypeDef = TypedDict(
     "_RequiredCreateComponentInputRequestTypeDef",
     {
@@ -3405,6 +3446,14 @@ UpdateServiceTemplateVersionOutputTypeDef = TypedDict(
     },
 )
 
+GetResourcesSummaryOutputTypeDef = TypedDict(
+    "GetResourcesSummaryOutputTypeDef",
+    {
+        "counts": CountsSummaryTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 GetRepositorySyncStatusOutputTypeDef = TypedDict(
     "GetRepositorySyncStatusOutputTypeDef",
     {
