@@ -37,7 +37,7 @@ Usage::
     service_updated_waiter: ServiceUpdatedWaiter = client.get_waiter("service_updated")
     ```
 """
-from botocore.waiter import Waiter as Boto3Waiter
+from botocore.waiter import Waiter
 
 from .type_defs import WaiterConfigTypeDef
 
@@ -55,7 +55,7 @@ __all__ = (
 )
 
 
-class ComponentDeletedWaiter(Boto3Waiter):
+class ComponentDeletedWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Waiter.ComponentDeleted)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/waiters/#componentdeletedwaiter)
@@ -68,7 +68,7 @@ class ComponentDeletedWaiter(Boto3Waiter):
         """
 
 
-class ComponentDeployedWaiter(Boto3Waiter):
+class ComponentDeployedWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Waiter.ComponentDeployed)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/waiters/#componentdeployedwaiter)
@@ -81,7 +81,7 @@ class ComponentDeployedWaiter(Boto3Waiter):
         """
 
 
-class EnvironmentDeployedWaiter(Boto3Waiter):
+class EnvironmentDeployedWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Waiter.EnvironmentDeployed)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/waiters/#environmentdeployedwaiter)
@@ -94,7 +94,7 @@ class EnvironmentDeployedWaiter(Boto3Waiter):
         """
 
 
-class EnvironmentTemplateVersionRegisteredWaiter(Boto3Waiter):
+class EnvironmentTemplateVersionRegisteredWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Waiter.EnvironmentTemplateVersionRegistered)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/waiters/#environmenttemplateversionregisteredwaiter)
@@ -114,7 +114,7 @@ class EnvironmentTemplateVersionRegisteredWaiter(Boto3Waiter):
         """
 
 
-class ServiceCreatedWaiter(Boto3Waiter):
+class ServiceCreatedWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Waiter.ServiceCreated)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/waiters/#servicecreatedwaiter)
@@ -127,7 +127,7 @@ class ServiceCreatedWaiter(Boto3Waiter):
         """
 
 
-class ServiceDeletedWaiter(Boto3Waiter):
+class ServiceDeletedWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Waiter.ServiceDeleted)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/waiters/#servicedeletedwaiter)
@@ -140,7 +140,7 @@ class ServiceDeletedWaiter(Boto3Waiter):
         """
 
 
-class ServiceInstanceDeployedWaiter(Boto3Waiter):
+class ServiceInstanceDeployedWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Waiter.ServiceInstanceDeployed)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/waiters/#serviceinstancedeployedwaiter)
@@ -153,7 +153,7 @@ class ServiceInstanceDeployedWaiter(Boto3Waiter):
         """
 
 
-class ServicePipelineDeployedWaiter(Boto3Waiter):
+class ServicePipelineDeployedWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Waiter.ServicePipelineDeployed)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/waiters/#servicepipelinedeployedwaiter)
@@ -166,7 +166,7 @@ class ServicePipelineDeployedWaiter(Boto3Waiter):
         """
 
 
-class ServiceTemplateVersionRegisteredWaiter(Boto3Waiter):
+class ServiceTemplateVersionRegisteredWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Waiter.ServiceTemplateVersionRegistered)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/waiters/#servicetemplateversionregisteredwaiter)
@@ -186,7 +186,7 @@ class ServiceTemplateVersionRegisteredWaiter(Boto3Waiter):
         """
 
 
-class ServiceUpdatedWaiter(Boto3Waiter):
+class ServiceUpdatedWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Waiter.ServiceUpdated)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/waiters/#serviceupdatedwaiter)
